package com.limap.demo.service;

import java.util.List;
import com.baomidou.mybatisplus.extension.service.IService;
import com.limap.demo.domain.DemoClasses;

/**
 * 主子表演示Service接口
 * 
 * @author metaee
 * @date 2023-02-28
 */
public interface IDemoClassesService extends IService<DemoClasses> {
    /**
     * 查询主子表演示列表
     * 
     * @param demoClasses 主子表演示
     * @return 主子表演示集合
     */
    public List<DemoClasses> selectDemoClassesList(DemoClasses demoClasses);
    /**
     * 查询主子表演示
     * 
     * @param classesId 主子表演示主键
     * @return 主子表演示
     */
    public DemoClasses selectDemoClassesByClassesId(Long classesId);

    /**
     * 新增主子表演示
     * 
     * @param demoClasses 主子表演示
     * @return 结果
     */
    public int insertDemoClasses(DemoClasses demoClasses);

    /**
     * 修改主子表演示
     * 
     * @param demoClasses 主子表演示
     * @return 结果
     */
    public int updateDemoClasses(DemoClasses demoClasses);

    /**
     * 批量删除主子表演示
     * 
     * @param classesIds 需要删除的主子表演示主键集合
     * @return 结果
     */
    public int deleteDemoClassesByClassesIds(Long[] classesIds);

    /**
     * 删除主子表演示信息
     * 
     * @param classesId 主子表演示主键
     * @return 结果
     */
    public int deleteDemoClassesByClassesId(Long classesId);
}
